<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;


class UsersController extends Controller
{
    public function index(){
          $users = User::where('user_type', 'tip')->get();
        return view('admin.users.index',  compact('users'));
    }
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
       
        $rules=
            [
              'first_name'=>"required",
              'last_name' =>'required',
              'email'  =>'required|unique:users,email',
              'city'  =>'required',
              'phone'  =>'required',
              'address_one'  =>'required',
              'postal_code'  =>'required',
              'uname'  =>'required',
              'password'  =>'required',
            ];
            $message=
            [
               'first_name.required' => 'First Name is require',
               'last_name.required' =>'Last Name is required',
               'email.required' =>'Email is required',
               'city.required' =>'City is required',
               'phone.required' =>'Phone Number is required',
               'address_one.required' =>'Address One is required',
               'postal_code.required' =>'Postal Code is required',
               'uname.required' =>'Username is required',
               'password.required' =>'Password is required',
            ]
        ;

        $validator = Validator::make($request->all(), $rules, $message);

        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator->getMessageBag())->with([
                'status' => 'add'
            ]);
        }
        $user= new User;
        $user->first_name = $request->first_name;
        $user->last_name =$request->last_name;
        $user->email =$request->email;
        $user->city =$request->city;
        $user->phone =$request->phone;
        $user->address_one =$request->address_one;
        $user->address_two =$request->address_two;
        $user->postal_code =$request->postal_code;
        $user->uname =$request->uname;
        $user->password =Hash::make($request->password);
        $user->user_type= $request->user_type;
        $user->status ='1';
        $user->save();
        return back()->with("success", "Added Successfully");
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules=
            [
              'first_name'=>"required",
              'last_name' =>'required',
              'email'  =>'required|unique:users,email,'.$id,
              'city'  =>'required',
              'phone'  =>'required',
              'address_one'  =>'required',
              'postal_code'  =>'required',
              'uname'  =>'required',
            ];
            $message=
            [
               'first_name.required' => 'First Name is require',
               'last_name.required' =>'Last Name is required',
               'email.required' =>'Email is required',
               'city.required' =>'City is required',
               'phone.required' =>'Phone Number is required',
               'address_one.required' =>'Address One is required',
               'postal_code.required' =>'Postal Code is required',
               'uname.required' =>'Username is required',
            ]
        ;

        $validator = Validator::make($request->all(), $rules, $message);

        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator->getMessageBag())->with([
                'status' => 'edit',
                'modal' => 'modeledit'.$id
            ]);
        }
        
        $user=User::findorfail($id);
        $user->first_name = $request->first_name;
        $user->last_name =$request->last_name;
        $user->email =$request->email;
        $user->city =$request->city;
        $user->phone =$request->phone;
        $user->address_one =$request->address_one;
        $user->address_two =$request->address_two;
        $user->postal_code =$request->postal_code;
        $user->uname =$request->uname;
        $user->update();
        return back()->with("success", "Updated Successfully");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
  
    public function destroy($id){
        $user = User::findOrFail($id);
        $user->delete();
        return back()->with("success", "Deleted Successfully");
    }
    
}
